@@ -17,6 +17,7 @@ from contextlib import suppress
 from copy import deepcopy
 from logging.config import dictConfig
 from textwrap import dedent
+from typing import Any, Callable, TypeVar, cast
 
 from traitlets.config.configurable import Configurable, SingletonConfigurable
 from traitlets.config.loader import (
@@ -94,8 +95,10 @@ else:
 
 IS_PYTHONW = sys.executable and sys.executable.endswith("pythonw.exe")
 
+T = TypeVar("T", bound=Callable[..., Any])
 
-def catch_config_error(method):
+
+def catch_config_error(method: T) -> T:
     """Method decorator for catching invalid config (Trait/ArgumentErrors) during init.
 
     On a TraitError (generally caused by bad config), this will print the trait's
@@ -113,7 +116,7 @@ def catch_config_error(method):
             app.log.debug("Config at the time: %s", app.config)
             app.exit(1)
 
-    return inner
+    return cast(T, inner)
 
 
 class ApplicationError(Exception):
